case $(uname -s) in *-WOW*) wow64=" (32-bit)" ;; esac
/usr/bin/mkdir -p "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}"
/usr/bin/mkshortcut $CYGWINFORALL -P -w / -i /usr/share/pixmaps/xwin/fluxbox.ico -n "Cygwin-X${wow64}/Fluxbox" -a "--quote /usr/bin/bash.exe -l -c \"cd; XSESSION_ICON=fluxbox exec /usr/bin/startx /etc/X11/xinit/Xsession fluxbox\"" /usr/bin/run.exe
