case $(uname -s) in *-WOW*) wow64=" (32-bit)" ;; esac
/bin/rm -f "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}/Fluxbox.lnk"
/bin/rmdir --ignore-fail-on-non-empty "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}"
